# Provival

## Main
Provival is a Python3 software package designed to score bulk RNA samples and single cells from scRNA-seq using a single quantitative index that measures bias towards revival or proliferative colon stem cell transcriptional states.

## Installation
```sh
pip install provival
```
## File Structure
<pre>     
├── README.md
├── provival.py                                                
├── setup.py
├── SC_DB_Human.pickle
├── SC_DB_Mouse.pickle
├── SC_DB_Metadata.pickle
</pre>

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

## Reference
Coming soon.
